Package: RivRetrieve
Title: Retrieve Global River Gauge Data
Version: 0.2.0
Authors@R: 
    c(person("Ryan", "Riggs", ,  "ryanriggs7@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0001-6834-9469")),
      person("Simon", "Moulds", , "sim.moulds@gmail.com", role = c("aut"), comment = c(ORCID = "0000-0002-7297-482X")),
      person("Michel", "Wortmann", , "michel.wortmann@ouce.ox.ac.uk",role=c("aut"), comment = c(ORCID = "0000-0002-1879-7674")),
      person("Louise", "Slater", , "louise.slater@ouce.ox.ac.uk",role=c("aut"), comment = c(ORCID = "0000-0001-9416-488X")),
      person("George", "Allen", , "geoallen@vt.edu",role=c("aut"), comment = c(ORCID = "0000-0001-8301-5301"))
      )
Description: Provides access to global river gauge data from a variety of national-level river agencies. The package interfaces with the national-level agency websites to provide access to river gauge locations, river discharge, and river stage. Currently, the package is available for the following countries: Argentina, Australia, Brazil, Canada, Chile, France, Germany, Japan, South Africa, the United Kingdom, and the United States.
License: MIT + file LICENSE
URL: https://github.com/Ryan-Riggs/RivRetrieve
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.1)
Imports: BBmisc, dataRetrieval, data.table, devtools, dplyr, httr,
        jsonlite, lubridate, readr, rlang, rlist, RSelenium, rvest,
        stringr, tibble, tidyhydat, tidyr
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-08-21 16:59:12 UTC; ryanr
Author: Ryan Riggs [aut, cre] (ORCID: <https://orcid.org/0000-0001-6834-9469>),
  Simon Moulds [aut] (ORCID: <https://orcid.org/0000-0002-7297-482X>),
  Michel Wortmann [aut] (ORCID: <https://orcid.org/0000-0002-1879-7674>),
  Louise Slater [aut] (ORCID: <https://orcid.org/0000-0001-9416-488X>),
  George Allen [aut] (ORCID: <https://orcid.org/0000-0001-8301-5301>)
Maintainer: Ryan Riggs <ryanriggs7@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-21 19:10:02 UTC
Built: R 4.5.2; ; 2026-08-22 00:18:49 UTC; unix
