# Generated by roxygen2: do not edit by hand

S3method(original,rr_tbl)
S3method(plot,rr_tbl)
export(argentina)
export(australia)
export(brazil)
export(canada)
export(chile)
export(france)
export(germany)
export(ireland)
export(japan)
export(original)
export(quebec)
export(scotland)
export(southAfrica)
export(sweden)
export(uk)
export(usa)
import(RSelenium)
import(dataRetrieval)
import(devtools)
import(dplyr)
import(httr)
import(jsonlite)
import(lubridate)
import(rvest)
import(stringr)
import(tibble)
import(tidyhydat)
import(tidyr)
importFrom(BBmisc,is.error)
importFrom(data.table,fread)
importFrom(readr,locale)
importFrom(readr,read_delim)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlist,list.select)
importFrom(rlist,list.stack)
importFrom(stats,na.omit)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stats,time)
importFrom(utils,download.file)
importFrom(utils,read.csv)
importFrom(utils,unzip)
