# RivRetrieve

[![metacran downloads](https://cranlogs.r-pkg.org/badges/grand-total/RivRetrieve)](https://cran.r-project.org/package=RivRetrieve) [![metacran downloads](https://cranlogs.r-pkg.org/badges/last-month/RivRetrieve)](https://cran.r-project.org/package=RivRetrieve) [![metacran downloads](https://cranlogs.r-pkg.org/badges/last-week/RivRetrieve)](https://cran.r-project.org/package=RivRetrieve)

An R package for locating and downloading global river gauge data for the following regions: Argentina, Australia, Brazil, Canada, Chile, France, Germany, Ireland, Japan, Quebec, Scotland, South Africa, Sweden, the United Kingdom, and the United States. Please see <https://doi.org/10.1088/1748-9326/acd407> for a detailed analysis on the gauge data.

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10125516.svg)](https://doi.org/10.5281/zenodo.10125516)
