#' RivRetrieve: Retrieve global river and stage data
#'
#' @aliases NULL RivRetrieve-package
#' @import dataRetrieval
#' @import devtools
#' @import dplyr
#' @import httr
#' @import jsonlite
#' @import lubridate
#' @import RSelenium
#' @import rvest
#' @import stringr
#' @import tibble
#' @import tidyhydat
#' @import tidyr
#' @importFrom BBmisc is.error
#' @importFrom readr read_delim locale
#' @importFrom rlist list.select list.stack
#' @importFrom rlang .data :=
#' @importFrom stats setNames time
#' @importFrom utils download.file unzip
#' @importFrom utils read.csv
#'
#' @examples
#' \dontrun{
#' print("TODO")
#' }
"_PACKAGE"
