% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/germany.R
\name{germany}
\alias{germany}
\title{germany}
\usage{
germany(
  site,
  variable = "discharge",
  start_date = NULL,
  end_date = NULL,
  sites = FALSE,
  ...
)
}
\arguments{
\item{site}{German gauge id.}

\item{variable}{Character. Either \code{stage} or \code{discharge}.}

\item{start_date}{Character. Optional start date with format
YYYY-MM-DD. Default is 1900-01-01.}

\item{end_date}{Character. End date with format YYYY-MM-DD.
Default is the current date.}

\item{sites}{Logical. If TRUE, returns a list of measurement
sites.}

\item{...}{Additional arguments. None implemented.}
}
\value{
data frame of discharge time-series
}
\description{
Retrieve German gauge data.
}
\examples{
\dontrun{
# Note the German API currently only provides access to stage data from the previous 30 days.
site <- "593647aa-9fea-43ec-a7d6-6476a76ae868"
stage <- germany(site, variable = "stage")
plot(stage$Date, stage$H, type = "l")
}
}
